# ttrpg-dice

Some stuff to help TTRPG gamesmasters with dice:

- a python library with useful calculations
- a jupyter notebook as a lazy interface to run the calculations
- a StatBlock class for constructing characters & beasts
